==> zio-aws-mediatailor_3-5.17.163.1-sources.jar: zio/aws/mediatailor/model/ScheduleEntry.scala <==
package zio.aws.mediatailor.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.mediatailor.model.primitives.{__string, __timestampUnix, __long}
import scala.jdk.CollectionConverters.*
final case class ScheduleEntry(
    approximateDurationSeconds: Optional[__long] = Optional.Absent,
    approximateStartTime: Optional[__timestampUnix] = Optional.Absent,
    arn: __string,
    channelName: __string,
    programName: __string,
    scheduleAdBreaks: Optional[
      Iterable[zio.aws.mediatailor.model.ScheduleAdBreak]
    ] = Optional.Absent,
    scheduleEntryType: Optional[zio.aws.mediatailor.model.ScheduleEntryType] =
      Optional.Absent,
    sourceLocationName: __string,
    vodSourceName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.ScheduleEntry = {
    import ScheduleEntry.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.ScheduleEntry
      .builder()
      .optionallyWith(
        approximateDurationSeconds.map(value => value: java.lang.Long)
      )(_.approximateDurationSeconds)
      .optionallyWith(approximateStartTime.map(value => value: Instant))(
        _.approximateStartTime
      )
      .arn(arn: java.lang.String)
      .channelName(channelName: java.lang.String)
      .programName(programName: java.lang.String)
      .optionallyWith(
        scheduleAdBreaks.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.scheduleAdBreaks)
      .optionallyWith(scheduleEntryType.map(value => value.unwrap))(
        _.scheduleEntryType
      )
      .sourceLocationName(sourceLocationName: java.lang.String)
      .vodSourceName(vodSourceName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.ScheduleEntry.ReadOnly =
    zio.aws.mediatailor.model.ScheduleEntry.wrap(buildAwsValue())
}
object ScheduleEntry {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.ScheduleEntry
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.ScheduleEntry =
      zio.aws.mediatailor.model.ScheduleEntry(
        approximateDurationSeconds.map(value => value),
        approximateStartTime.map(value => value),
        arn,
        channelName,
        programName,
        scheduleAdBreaks.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        scheduleEntryType.map(value => value),
        sourceLocationName,
        vodSourceName
      )
    def approximateDurationSeconds: Optional[__long]
    def approximateStartTime: Optional[__timestampUnix]
    def arn: __string
    def channelName: __string
    def programName: __string
    def scheduleAdBreaks
        : Optional[List[zio.aws.mediatailor.model.ScheduleAdBreak.ReadOnly]]
    def scheduleEntryType: Optional[zio.aws.mediatailor.model.ScheduleEntryType]
    def sourceLocationName: __string
    def vodSourceName: __string
    def getApproximateDurationSeconds: ZIO[Any, AwsError, __long] =
      AwsError.unwrapOptionField(
        "approximateDurationSeconds",
        approximateDurationSeconds
      )
    def getApproximateStartTime: ZIO[Any, AwsError, __timestampUnix] =
      AwsError.unwrapOptionField("approximateStartTime", approximateStartTime)
    def getArn: ZIO[Any, Nothing, __string] = ZIO.succeed(arn)
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
    def getProgramName: ZIO[Any, Nothing, __string] = ZIO.succeed(programName)
    def getScheduleAdBreaks: ZIO[Any, AwsError, List[
      zio.aws.mediatailor.model.ScheduleAdBreak.ReadOnly
    ]] = AwsError.unwrapOptionField("scheduleAdBreaks", scheduleAdBreaks)
    def getScheduleEntryType
        : ZIO[Any, AwsError, zio.aws.mediatailor.model.ScheduleEntryType] =
      AwsError.unwrapOptionField("scheduleEntryType", scheduleEntryType)
    def getSourceLocationName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(sourceLocationName)
    def getVodSourceName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(vodSourceName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.ScheduleEntry
  ) extends zio.aws.mediatailor.model.ScheduleEntry.ReadOnly {
    override val approximateDurationSeconds: Optional[__long] =
      zio.aws.core.internal
        .optionalFromNullable(impl.approximateDurationSeconds())
        .map(value => value: __long)
    override val approximateStartTime: Optional[__timestampUnix] =
      zio.aws.core.internal
        .optionalFromNullable(impl.approximateStartTime())
        .map(value => value: __timestampUnix)
    override val arn: __string = impl.arn(): __string
    override val channelName: __string = impl.channelName(): __string
    override val programName: __string = impl.programName(): __string
    override val scheduleAdBreaks
        : Optional[List[zio.aws.mediatailor.model.ScheduleAdBreak.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.scheduleAdBreaks())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.mediatailor.model.ScheduleAdBreak.wrap(item)
          }.toList
        )
    override val scheduleEntryType
        : Optional[zio.aws.mediatailor.model.ScheduleEntryType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.scheduleEntryType())
        .map(value => zio.aws.mediatailor.model.ScheduleEntryType.wrap(value))
    override val sourceLocationName: __string =
      impl.sourceLocationName(): __string
    override val vodSourceName: __string = impl.vodSourceName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.ScheduleEntry
  ): zio.aws.mediatailor.model.ScheduleEntry.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.17.257.1-sources.jar: zio/aws/mediatailor/model/ScheduleEntry.scala <==
package zio.aws.mediatailor.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.mediatailor.model.primitives.{__string, __timestampUnix, __long}
import scala.jdk.CollectionConverters.*
final case class ScheduleEntry(
    approximateDurationSeconds: Optional[__long] = Optional.Absent,
    approximateStartTime: Optional[__timestampUnix] = Optional.Absent,
    arn: __string,
    channelName: __string,
    liveSourceName: Optional[__string] = Optional.Absent,
    programName: __string,
    scheduleAdBreaks: Optional[
      Iterable[zio.aws.mediatailor.model.ScheduleAdBreak]
    ] = Optional.Absent,
    scheduleEntryType: Optional[zio.aws.mediatailor.model.ScheduleEntryType] =
      Optional.Absent,
    sourceLocationName: __string,
    vodSourceName: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.ScheduleEntry = {
    import ScheduleEntry.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.ScheduleEntry
      .builder()
      .optionallyWith(
        approximateDurationSeconds.map(value => value: java.lang.Long)
      )(_.approximateDurationSeconds)
      .optionallyWith(approximateStartTime.map(value => value: Instant))(
        _.approximateStartTime
      )
      .arn(arn: java.lang.String)
      .channelName(channelName: java.lang.String)
      .optionallyWith(liveSourceName.map(value => value: java.lang.String))(
        _.liveSourceName
      )
      .programName(programName: java.lang.String)
      .optionallyWith(
        scheduleAdBreaks.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.scheduleAdBreaks)
      .optionallyWith(scheduleEntryType.map(value => value.unwrap))(
        _.scheduleEntryType
      )
      .sourceLocationName(sourceLocationName: java.lang.String)
      .optionallyWith(vodSourceName.map(value => value: java.lang.String))(
        _.vodSourceName
      )
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.ScheduleEntry.ReadOnly =
    zio.aws.mediatailor.model.ScheduleEntry.wrap(buildAwsValue())
}
object ScheduleEntry {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.ScheduleEntry
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.ScheduleEntry =
      zio.aws.mediatailor.model.ScheduleEntry(
        approximateDurationSeconds.map(value => value),
        approximateStartTime.map(value => value),
        arn,
        channelName,
        liveSourceName.map(value => value),
        programName,
        scheduleAdBreaks.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        scheduleEntryType.map(value => value),
        sourceLocationName,
        vodSourceName.map(value => value)
      )
    def approximateDurationSeconds: Optional[__long]
    def approximateStartTime: Optional[__timestampUnix]
    def arn: __string
    def channelName: __string
    def liveSourceName: Optional[__string]
    def programName: __string
    def scheduleAdBreaks
        : Optional[List[zio.aws.mediatailor.model.ScheduleAdBreak.ReadOnly]]
    def scheduleEntryType: Optional[zio.aws.mediatailor.model.ScheduleEntryType]
    def sourceLocationName: __string
    def vodSourceName: Optional[__string]
    def getApproximateDurationSeconds: ZIO[Any, AwsError, __long] =
      AwsError.unwrapOptionField(
        "approximateDurationSeconds",
        approximateDurationSeconds
      )
    def getApproximateStartTime: ZIO[Any, AwsError, __timestampUnix] =
      AwsError.unwrapOptionField("approximateStartTime", approximateStartTime)
    def getArn: ZIO[Any, Nothing, __string] = ZIO.succeed(arn)
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
    def getLiveSourceName: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("liveSourceName", liveSourceName)
    def getProgramName: ZIO[Any, Nothing, __string] = ZIO.succeed(programName)
    def getScheduleAdBreaks: ZIO[Any, AwsError, List[
      zio.aws.mediatailor.model.ScheduleAdBreak.ReadOnly
    ]] = AwsError.unwrapOptionField("scheduleAdBreaks", scheduleAdBreaks)
    def getScheduleEntryType
        : ZIO[Any, AwsError, zio.aws.mediatailor.model.ScheduleEntryType] =
      AwsError.unwrapOptionField("scheduleEntryType", scheduleEntryType)
    def getSourceLocationName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(sourceLocationName)
    def getVodSourceName: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("vodSourceName", vodSourceName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.ScheduleEntry
  ) extends zio.aws.mediatailor.model.ScheduleEntry.ReadOnly {
    override val approximateDurationSeconds: Optional[__long] =
      zio.aws.core.internal
        .optionalFromNullable(impl.approximateDurationSeconds())
        .map(value => value: __long)
    override val approximateStartTime: Optional[__timestampUnix] =
      zio.aws.core.internal
        .optionalFromNullable(impl.approximateStartTime())
        .map(value => value: __timestampUnix)
    override val arn: __string = impl.arn(): __string
    override val channelName: __string = impl.channelName(): __string
    override val liveSourceName: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.liveSourceName())
      .map(value => value: __string)
    override val programName: __string = impl.programName(): __string
    override val scheduleAdBreaks
        : Optional[List[zio.aws.mediatailor.model.ScheduleAdBreak.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.scheduleAdBreaks())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.mediatailor.model.ScheduleAdBreak.wrap(item)
          }.toList
        )
    override val scheduleEntryType
        : Optional[zio.aws.mediatailor.model.ScheduleEntryType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.scheduleEntryType())
        .map(value => zio.aws.mediatailor.model.ScheduleEntryType.wrap(value))
    override val sourceLocationName: __string =
      impl.sourceLocationName(): __string
    override val vodSourceName: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.vodSourceName())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.ScheduleEntry
  ): zio.aws.mediatailor.model.ScheduleEntry.ReadOnly = new Wrapper(impl)
}
